# Lucidic Python Dictionary Utility Package Changelog

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [Unreleased]

## ['0.1.0'] - 2019-12-23

### Added

- Dictionary Search, loose or exact search for keyword through entire dict including dict and list values by [@rnason](https://github.com/rnason).
- Docstrings for all internal and public class methods by [@rnason](https://github.com/rnason).

### Changed

### Removed

<!-- markdownlint-disable MD024 -->
## [1.0.0-alpha.0] - 2019-12-27

### Added

- Functional Unit tests for all methods
- Readme updated to document currently available methods

### Changed

- Logic refactored to ensure recursive search through list objects
- Main search divided into smaller methods to match, recursively search nested dicts objects, and recursively search nested lists.

### Removed
